<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Slider_admin extends \Ciext\Controller\AbstractAdminController
{

    public function index()
    {
        $this->load->model('slider/crud_slider');

        return ['content' => $this->crud_slider->render(), 'title' => $this->lang->line('Sliders')];
    }

    public function slide()
    {
        $this->load->model('slider/crud_slide');

        return ['content' => $this->crud_slide->render(), 'title' => $this->lang->line('Slides')];
    }

}
